@@ -132,12 +132,12 @@ class AbstractConverter(object):
 
     It is an abstract class, with some abstract functions which should be
     overriden :
-      - get_input_height
-      - get_input_width
-      - get_page_count
-      - bookletize
-      - linearize
-      - reduce
+    - get_input_height
+    - get_input_width
+    - get_page_count
+    - bookletize
+    - linearize
+    - reduce
     """
     __metaclass__ = ABCMeta
 
@@ -157,11 +157,11 @@ class AbstractConverter(object):
         Create an AbstractConverter instance.
 
         :Parameters:
-          - `layout`: The layout of input pages on one output page
+          - `layout` The layout of input pages on one output page
             (see set_layout).
-          - `format`: The format of the output paper (see
+          - `format` The format of the output paper (see
             set_output_format).
-          - `copy_pages`: Wether the same group of input pages
+          - `copy_pages` Wether the same group of input pages
             shoud be copied to fill the corresponding output page or not
             (see set_copy_pages).
         """
@@ -186,7 +186,7 @@ class AbstractConverter(object):
         Set the height of the output page.
 
         :Parameters:
-          - `height`: The height of the output page in defalut user
+          - `height` The height of the output page in defalut user
             space units.
         """
         self.__output_height = int(height)
@@ -204,7 +204,7 @@ class AbstractConverter(object):
         """
         Set the width of the output page.
 
-          - `width`: The height of the output page in defalut user space units.
+          - `width` The height of the output page in defalut user space units.
         """
         self.__output_width = int(width)
 
@@ -222,7 +222,7 @@ class AbstractConverter(object):
         Set the number of input pages to put in the width on one output page.
 
         :Parameters:
-          - `num`: An integer representing the number of pages in width.
+          - `num` An integer representing the number of pages in width.
         """
         self.__pages_in_width = int(num)
 
@@ -240,7 +240,7 @@ class AbstractConverter(object):
         Set the number of input pages to put in the height on one output page.
 
         :Parameters:
-          - `num`: An integer representing the number of pages in height.
+          - `num` An integer representing the number of pages in height.
         """
         self.__pages_in_height = int(num)
 
@@ -258,7 +258,8 @@ class AbstractConverter(object):
         Set wether the same group of input pages shoud be copied to fill the
         corresponding output page or not.
 
-          - `copy_page`: True to get copies of the same group of input page
+        :Parameters:
+          - `copy_pages` True to get copies of the same group of input page
             on one output page. False to get diffrent groups of
             input pages on one output page.
         """
@@ -284,7 +285,7 @@ class AbstractConverter(object):
         progress of the conversion.
 
         :Parameters:
-          - `progress_callback`: The callback function which is called to
+          - `progress_callback` The callback function which is called to
             return the conversion progress. Its signature
             must be : a string for the progress message;
             a number in the range [0, 1] for the progress.
@@ -359,7 +360,7 @@ class AbstractConverter(object):
         Set the layout of input pages on one output page.
 
         :Parameters:
-          - `layout`: A string of the form WxH, where W is the number of input
+          - `layout` A string of the form WxH, where W is the number of input
             pages to put on the width of the output page and H is
             the number of input pages to put in the height of an
             output page.
@@ -394,11 +395,10 @@ class AbstractConverter(object):
         Set the format of the output paper.
 
         :Parameters:
-          - `format`: A string representing name ot the the desired paper
+          - `format` A string representing name ot the the desired paper
             format, among the keys of page_formats (e.g. A3, A4, A5).
 
-        :Raises:
-          - UnknonwFormatError if the given paper format is not recognized.
+        :Raises UnknonwFormatError: if the given paper format is not recognized.
         """
         try:
             width, height = AbstractConverter.page_formats[format]
@@ -416,7 +416,7 @@ class AbstractConverter(object):
             (e.g. A3, A4, A5).
         """
         for output_format in AbstractConverter.page_formats.keys():
-            if AbstractPdfConv.page_formats[output_format] == \
+            if AbstractConverter.page_formats[output_format] == \
                 (self.get_output_width, self.get_output_height):
                 return output_format
 
@@ -478,7 +478,7 @@ class AbstractConverter(object):
         manually.
 
         :Parameters:
-          - `output_orientation`: A constant from PageOrientation,
+          - `output_orientation` A constant from PageOrientation,
             or None (if square paper).
         """
         output_orientation = bool(output_orientation)
@@ -496,7 +496,7 @@ class AbstractConverter(object):
         Return the orientation of the output paper.
 
         WARNING: in the current implementation, the orientation of the
-        output paper may be automatically adjusted, even if ti was set
+        output paper may be automatically adjusted, even if it was set
         manually.
 
         :Returns:
@@ -507,7 +507,6 @@ class AbstractConverter(object):
         elif self.get_output_height() < self.get_output_width():
             return PageOrientation.LANDSCAPE
         else:
-            #XXX: is square
             return None
 
     # CONVERSION FUNCTIONS
@@ -557,14 +556,14 @@ class StreamConverter(AbstractConverter):
         Create a StreamConverter.
 
         :Parameters:
-          - `input_stream`: The file-like object from which tne input PDF
+          - `input_stream` The file-like object from which tne input PDF
             document should be read.
-          - `output_stream`: The file-like object to which tne output PDF
+          - `output_stream` The file-like object to which tne output PDF
             document should be written.
-          - `layout`: The layout of input pages on one output page (see
+          - `layout` The layout of input pages on one output page (see
             set_layout).
-          - `format`: The format of the output paper (see set_output_format).
-          - `copy_pages`: Wether the same group of input pages shoud be copied
+          - `format` The format of the output paper (see set_output_format).
+          - `copy_pages` Wether the same group of input pages shoud be copied
             to fill the corresponding output page or not (see
             set_copy_pages).
         """
@@ -597,26 +596,24 @@ class StreamConverter(AbstractConverter):
         Adapt the output page orientation.
 
         :Parameters:
-          - `cmp`: A comparator function. Takes: number of pages on one
+          - `cmp` A comparator function. Takes: number of pages on one
             direction (int), number of pages on the other direction
             (int). Must return: the boolean result of the comparaison.
 
-        :Raises:
-          - MismachingOrientationsError if the required layout is
+        :Raises MismachingOrientationsError: if the required layout is
             incompatible with the input page orientation.
         """
         if cmp(self.get_pages_in_width(), self.get_pages_in_height()):
             if self.get_input_orientation() == PageOrientation.PORTRAIT:
                 if self._get_output_orientation() == PageOrientation.PORTRAIT:
                     self._set_output_orientation(PageOrientation.LANDSCAPE)
-            else: #if self.get_input_orientation() == PageOrientation.LANDSCAPE:
+            else:
                 raise MismachingOrientationsError(self.get_layout())
         elif cmp(self.get_pages_in_height(), self.get_pages_in_width()):
             if self.get_input_orientation() == PageOrientation.LANDSCAPE:
                 if self._get_output_orientation() == PageOrientation.LANDSCAPE:
                     self._set_output_orientation(PageOrientation.PORTRAIT)
             else:
-                # XXX: Localized error message
                 raise MismachingOrientationsError(self.get_layout())
         else:
             if self.get_input_orientation() == PageOrientation.LANDSCAPE:
@@ -628,7 +625,7 @@ class StreamConverter(AbstractConverter):
 
     def __fix_page_orientation_for_booklet(self):
         """
-        Adapt the output page orientation
+        Adapt the output page orientation to impose
         """
         def __is_two_times(op1, op2):
             if op1 == 2 * op2:
@@ -636,20 +633,26 @@ class StreamConverter(AbstractConverter):
             else:
                 return False
         self.__fix_page_orientation(__is_two_times)
-        #self.__fix_page_orientation(lambda op1, op2: [False, True][op1 == 2 * op2])
 
     def __fix_page_orientation_for_linearize(self):
+        """
+        Adapt the output page orientation to linearize
+        """
         def __is_half(op1, op2):
             if op2 == 2 * op1:
                 return True
             else:
                 return False
         self.__fix_page_orientation(__is_half)
-        #self.__fix_page_orientation(lambda op1, op2: [False, True][op2 == 2 * op1])
 
     def __get_sequence_for_booklet(self):
         """
-        XXX: Documentation
+        Calculates the page sequence to impose a booklet.
+
+        :Returns:
+            A list of page numbers representing sequence of pages to
+            impose a booklet. The list might contain None where blank
+            pages should be added.
         """
         n_pages = self.get_page_count()
         pages = range(0, n_pages)
@@ -658,19 +661,16 @@ class StreamConverter(AbstractConverter):
         if (n_pages % 4) == 0:
             n_missing_pages = 0
         else:
-            #n_missing_pages = (4 - (n_pages % 4)) / self.get_pages_in_sheet()
             n_missing_pages = 4 - (n_pages % 4)
-            # XXX: afficher un warning (autre callback ?)
-            # si le nombre de pages n'est pas divisible par 4 ?
+            # XXX: print a warning if input page number not diviable by 4?
 
         # Add reference to the missing empty pages to the pages sequence
         for missing_page in range(0, n_missing_pages):
             pages.append(None)
 
-        # XXX: Document this
         def append_and_copy(list, pages):
             """
-            XXX: Doc
+            Append pages to the list and copy them if needed
             """
             if self.get_copy_pages():
                 for i in range(self.get_pages_in_sheet() / 2):
@@ -680,7 +680,7 @@ class StreamConverter(AbstractConverter):
 
         # Arranges the pages in booklet order
         sequence = []
-        while pages :
+        while pages:
             append_and_copy(sequence, [pages.pop(), pages.pop(0)])
             append_and_copy(sequence, [pages.pop(0), pages.pop()])
 
@@ -688,9 +688,13 @@ class StreamConverter(AbstractConverter):
 
     def __get_sequence_for_linearize(self, booklet=True):
         """
-        XXX: Doc
+        Calculates the page sequence to lineraize a booklet.
+
+        :Returns:
+            A list of page numbers representing sequence of pages to
+            be extracted to linearize a booklet.
         """
-        # XXX: booklet argument is not useful ?
+        # XXX: is booklet argument useful?
 
         def append_and_remove_copies(list, pages):
             sequence.extend(pages)
@@ -709,12 +713,17 @@ class StreamConverter(AbstractConverter):
                 # XXX: Print a warning
                 pass
         else:
-            sequence = range(0, npages * self.get_pages_in_sheet())
+            sequence = range(0, self.get_page_count() * self.get_pages_in_sheet())
         return sequence
 
     def __get_sequence_for_reduce(self):
         """
-        XXX: Doc
+        Calculates the page sequence to linearly impose reduced pages.
+
+        :Returns:
+            A list of page numbers representing sequence of pages to
+            impose reduced pages. The list might contain None where blank
+            pages should be added.
         """
         if self.get_copy_pages():
             sequence = []
@@ -730,11 +739,27 @@ class StreamConverter(AbstractConverter):
         return sequence
 
     def __write_output_stream(self, outpdf):
+        """
+        Writes output to the stream.
+
+        :Parameters:
+          - `outpdf` the object to write to the stream. This object must have a
+            write() method.
+        """
         self.get_progress_callback()(_("writing converted file"), 1)
         outpdf.write(self._output_stream)
         self.get_progress_callback()(_("done"), 1)
 
     def __do_reduce(self, sequence):
+        """
+        Do actual imposition job.
+
+        :Parameters:
+          - `sequence` a list of page numbers repersenting the sequence of
+            pages to impose. None means blank page.
+
+        """
+        # XXX: Translated progress messages
         self.__fix_page_orientation_for_booklet()
         outpdf = pyPdf.PdfFileWriter()
 
@@ -750,7 +775,7 @@ class StreamConverter(AbstractConverter):
                 self.get_output_height())
             for vert_pos in range(0, self.get_pages_in_height()):
                 for horiz_pos in range(0, self.get_pages_in_width()):
-                    if sequence[current_page] is not None:
+                    if current_page < len(sequence) and sequence[current_page] is not None:
                         page.mergeScaledTranslatedPage(
                             self._inpdf.getPage(sequence[current_page]),
                             self.get_reduction_factor(), 
@@ -765,7 +790,6 @@ class StreamConverter(AbstractConverter):
         self.__write_output_stream(outpdf)
 
     def bookletize(self):
-        # XXX: Translated progress messages
         self.__do_reduce(self.__get_sequence_for_booklet())
 
     def reduce(self):
@@ -773,7 +797,7 @@ class StreamConverter(AbstractConverter):
 
     def linearize(self, booklet=True):
         # XXX: Translated progress messages
-        # XXX: Mauvais facteur de zoom quand 2x1 p. ex
+        # XXX: Wrong zoom factor e.g. when layout is 2x1
 
         self.__fix_page_orientation_for_linearize()
         sequence = self.__get_sequence_for_linearize()
@@ -818,17 +842,17 @@ class FileConverter(StreamConverter):
         Create a FileConverter.
 
         :Parameters:
-          - `infile_name`: The name to the input PDF file.
-          - `outfile_name`: The name of the file where the output PDF
+          - `infile_name` The name to the input PDF file.
+          - `outfile_name` The name of the file where the output PDF
             should de written. If ommited, defaults to the
             name of the input PDF postponded by '-conv'.
-          - `layout`: The layout of input pages on one output page (see
+          - `layout` The layout of input pages on one output page (see
             set_layout).
-          - `format`: The format of the output paper (see set_output_format).
-          - `copy_pages`: Wether the same group of input pages shoud be copied
+          - `format` The format of the output paper (see set_output_format).
+          - `copy_pages` Wether the same group of input pages shoud be copied
             to fill the corresponding output page or not (see
             set_copy_pages).
-          - `overwrite_outfile_callback`: A callback function which is called
+          - `overwrite_outfile_callback` A callback function which is called
             if outfile_name already exists when trying to open it. Its
             signature must be : take a string for the outfile_name as an argument;
             return False not to overwrite the file. If ommited, existing file
@@ -885,6 +909,13 @@ class FileConverter(StreamConverter):
     # ===========================
 
     def __set_infile_name(self, name):
+        """
+        Sets the name of the input PDF file. Also set the name of output PDF
+        file if not already set.
+
+        :Parameters:
+          - `name` the name of the input PDF file.
+        """
         self.__infile_name = name
 
         if not self.__outfile_name:
@@ -904,6 +935,12 @@ class FileConverter(StreamConverter):
         return self.__infile_name
 
     def __set_outfile_name(self, name):
+        """
+        Sets the name of the output PDF file.
+
+        :Parameters:
+          - `name` the name of the output PDF file.
+        """
         self.__outfile_name = name
 
     def get_outfile_name(self):
@@ -916,7 +953,7 @@ class FileConverter(StreamConverter):
         return self.__outfile_name
 
 
-# Convenience fucntions
+# Convenience functions
 # =====================
 
 def bookletize_on_stream(input_stream, 
@@ -933,14 +970,14 @@ def bookletize_on_stream(input_stream,
     This is a convenience function around StreamConverter
 
     :Parameters:
-      - `input_stream`: The file-like object from which tne input PDF
+      - `input_stream` The file-like object from which tne input PDF
         document should be read.
-      - `output_stream`: The file-like object to which tne output PDF
+      - `output_stream` The file-like object to which tne output PDF
         document should be written.
-      - `layout`: The layout of input pages on one output page (see
+      - `layout` The layout of input pages on one output page (see
         set_layout).
-      - `format`: The format of the output paper (see set_output_format).
-      - `copy_pages`: Wether the same group of input pages shoud be copied
+      - `format` The format of the output paper (see set_output_format).
+      - `copy_pages` Wether the same group of input pages shoud be copied
         to fill the corresponding output page or not (see
         set_copy_pages).
     """
@@ -961,14 +998,14 @@ def bookletize_on_file(input_file,
     This is a convenience function around FileConverter
 
     :Parameters:
-      - `input_file`: The name to the input PDF file.
-      - `output_file`: The name of the file where the output PDF
+      - `input_file` The name to the input PDF file.
+      - `output_file` The name of the file where the output PDF
         should de written. If ommited, defaults to the
         name of the input PDF postponded by '-conv'.
-      - `layout`: The layout of input pages on one output page (see
+      - `layout` The layout of input pages on one output page (see
         set_layout).
-      - `format`: The format of the output paper (see set_output_format).
-      - `copy_pages`: Wether the same group of input pages shoud be copied
+      - `format` The format of the output paper (see set_output_format).
+      - `copy_pages` Wether the same group of input pages shoud be copied
         to fill the corresponding output page or not (see
         set_copy_pages).
     """
@@ -989,14 +1026,14 @@ def linearize_on_stream(input_stream,
     This is a convenience function around StreamConverter
 
     :Parameters:
-      - `input_stream`: The file-like object from which tne input PDF
+      - `input_stream` The file-like object from which tne input PDF
         document should be read.
-      - `output_stream`: The file-like object to which tne output PDF
+      - `output_stream` The file-like object to which tne output PDF
         document should be written.
-      - `layout`: The layout of output pages on one input page (see
+      - `layout` The layout of output pages on one input page (see
         set_layout).
-      - `format`: The format of the output paper (see set_output_format).
-      - `copy_pages`: Wether the same group of input pages shoud be copied
+      - `format` The format of the output paper (see set_output_format).
+      - `copy_pages` Wether the same group of input pages shoud be copied
         to fill the corresponding output page or not (see
         set_copy_pages).
     """
@@ -1017,14 +1054,14 @@ def linearize_on_file(input_file,
     This is a convenience function around FileConverter
 
     :Parameters:
-      - `input_file`: The name to the input PDF file.
-      - `output_file`: The name of the file where the output PDF
+      - `input_file` The name to the input PDF file.
+      - `output_file` The name of the file where the output PDF
         should de written. If ommited, defaults to the
         name of the input PDF postponded by '-conv'.
-      - `layout`: The layout of input pages on one output page (see
+      - `layout` The layout of input pages on one output page (see
         set_layout).
-      - `format`: The format of the output paper (see set_output_format).
-      - `copy_pages`: Wether the same group of input pages shoud be copied
+      - `format` The format of the output paper (see set_output_format).
+      - `copy_pages` Wether the same group of input pages shoud be copied
         to fill the corresponding output page or not (see
         set_copy_pages).
     """
@@ -1042,14 +1079,14 @@ def reduce_on_stream(input_stream,
     This is a convenience function around StreamConverter
 
     :Parameters:
-      - `input_stream`: The file-like object from which tne input PDF
+      - `input_stream` The file-like object from which tne input PDF
         document should be read.
-      - `output_stream`: The file-like object to which tne output PDF
+      - `output_stream` The file-like object to which tne output PDF
         document should be written.
-      - `layout`: The layout of input pages on one output page (see
+      - `layout` The layout of input pages on one output page (see
         set_layout).
-      - `format`: The format of the output paper (see set_output_format).
-      - `copy_pages`: Wether the same group of input pages shoud be copied
+      - `format` The format of the output paper (see set_output_format).
+      - `copy_pages` Wether the same group of input pages shoud be copied
         to fill the corresponding output page or not (see
         set_copy_pages).
     """
@@ -1067,14 +1104,14 @@ def reduce_on_file(input_file,
     This is a convenience function around FileConverter
 
     :Parameters:
-      - `input_file`: The name to the input PDF file.
-      - `output_file`: The name of the file where the output PDF
+      - `input_file` The name to the input PDF file.
+      - `output_file` The name of the file where the output PDF
         should de written. If ommited, defaults to the
         name of the input PDF postponded by '-conv'.
-      - `layout`: The layout of input pages on one output page (see
+      - `layout` The layout of input pages on one output page (see
         set_layout).
-      - `format`: The format of the output paper (see set_output_format).
-      - `copy_pages`: Wether the same group of input pages shoud be copied
+      - `format` The format of the output paper (see set_output_format).
+      - `copy_pages` Wether the same group of input pages shoud be copied
         to fill the corresponding output page or not (see
         set_copy_pages).
     """
